<?php
/**
 * WP Smart Content helps us add content to the WordPress template in a simple and smart way.
 *
 * @package wpsc.
 *
 * Plugin Name: WP Smart Content
 * Plugin URI: https://www.vinodsebastian.com/plugins
 * Description: WP Smart Content helps us add content to the WordPress template in a simple and smart way. The code  can be added to specific posts or pages or can be added site-wide. The plugin can push varied content like html, javascript, css to different parts of each WordPress post or page. An example would be to add a script to head section. Another example would be to add html to the footer. The content is stored in WordPress database and it can be easily removed by uninstalling it. It is a good companion for adding tracking code, javascript or style to specific or all posts and pages from a central settings page.
 * Version: 1.1.4
 * Author: Vinod Sebastian
 * Author URI: https://www.vinodsebastian.com
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Created Date: 13/07/18
 * Updated Date: 28/06/21
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
if ( ! class_exists( 'WPSC' ) ) :
	/**
	 * Class for WP Smart Content
	 */
	class WPSC {
		const SCRIPT_DEBUG = false;

		/**
		 * Refers to a single instance of this class.
		 *
		 * @var object $instance Instance.
		 */
		private static $instance;

		/**
		 * Registers the plugin using singleton pattern.
		 */
		public static function get_instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		} // end get_instance;

		/**
		 * Initializes the plugin by setting localization, filters, and administration functions.
		 */
		private function __construct() {
			add_action( 'init', array( $this, 'init_plugin' ) );

			add_action(
				'admin_menu',
				function() {
					add_options_page( 'WP Smart Content', 'WP Smart Content', 'manage_options', 'wpsc_settings', array( $this, 'admin_screen' ) );
				}
			);

			add_action( 'admin_init', array( $this, 'register_options' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'register_assets' ) );

			add_action( 'wp_ajax_wpsc_update_post', array( $this, 'wp_ajax_wpsc_update_post' ) );
			add_action( 'wp_ajax_wpsc_toggle_status_post', array( $this, 'wp_ajax_wpsc_toggle_status_post' ) );
			add_action( 'wp_ajax_wpsc_delete_post', array( $this, 'wp_ajax_wpsc_delete_post' ) );
		} // end constructor

		/**
		 * Invoked at init Hook
		 */
		public function init_plugin() {
			if ( true === $this->is_frontend() ) {
				// For front end.
				add_action( 'wp_print_styles', array( $this, 'display_frontend_content' ) );
				add_action( 'wp_print_scripts', array( $this, 'display_frontend_content' ) );
				add_action( 'wp_head', array( $this, 'display_frontend_content' ) );
				add_action( 'wp_meta', array( $this, 'display_frontend_content' ) );
				add_action( 'wp_footer', array( $this, 'display_frontend_content' ) );
				add_action( 'wp_print_footer_scripts', array( $this, 'display_frontend_content' ) );
			}
		}

		/**
		 * Registers assets.
		 *
		 * @return void
		 */
		public function register_assets() {
			$screen = get_current_screen();

			if ( null === $screen ) {
				return;
			}

			if ( in_array( $screen->id, array( 'settings_page_wpsc_settings' ), true ) ) {
				$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

				$my_js_url  = plugin_dir_url( __FILE__ ) . "assets/js/wpsc{$min}.js";
				$my_css_url = plugin_dir_url( __FILE__ ) . 'assets/css/wpsc.css';

				$my_js_path  = plugin_dir_path( __FILE__ ) . "/assets/js/wpsc{$min}.js";
				$my_css_path = plugin_dir_path( __FILE__ ) . '/assets/css/wpsc.css';

				$my_js_version  = gmdate( 'ymd-Gis', filemtime( $my_js_path ) );
				$my_css_version = gmdate( 'ymd-Gis', filemtime( $my_css_path ) );

				// Scripts.
				$wpsc_js = wp_register_script( 'wpsc_js', $my_js_url, array( 'jquery', 'jquery-ui-core' ), $my_js_version, true );
				wp_localize_script(
					'wpsc_js',
					'ajax_var',
					array(
						'url'   => admin_url( 'admin-ajax.php' ),
						'nonce' => wp_create_nonce( 'wpsc_nonce' ),
					)
				);
				wp_enqueue_script( 'wpsc_js', $my_js_url, array( 'jquery', 'jquery-ui-core' ), $my_js_version, true );

				// Styles.
				$wpsc_css = wp_register_style( 'wpsc_css', $my_css_url, array(), $my_css_version );
				wp_enqueue_style( 'wpsc_css', $my_css_url, array(), $my_css_version );
			}
		}

		/**
		 * Admin screen.
		 *
		 * @return void
		 */
		public function admin_screen() {
			$plugin_data    = get_plugin_data( __FILE__ );
			$plugin_version = $plugin_data['Version'];

			$str = "<div id='wpsc'>";
			$str = $str . "<div id='toTop'>To The Top!</div>";
			$str = $str . "<div class='banner table' style='margin-top:24px; padding-bottom:5px;'><img src='" . plugin_dir_url( __FILE__ ) . "assets/images/icon.png' style='clear:both; float:left; width:64px;' /><h1 style='clear:both; float:left; line-height:1.16em; width:100%; margin:0px;' class='blue'><span style='float:left;'>" . __( 'WP Smart Content', 'wpsc' ) . "&nbsp;</span><span style='float:left; font-size:14px; font-size:.75em; font-weight:600; line-height:1.85em;'>" . 'v' . $plugin_version . "</span>&nbsp;<span style='clear:both; float:left; font-size:14px;'>by Vinod Sebastian&nbsp;</span><span style='float:left; font-size:14px;'>(Support: business@vinodsebastian.com)</span></h1><p style='float:right; margin-left:10px; margin-right:10px;'><a target='_blank' class='button-primary' rel='noopener noreferrer' href='https://wordpress.org/plugins/wp-smart-content/#reviews'>OK, I'll leave a review</a></p><p style='float:right; margin-left:10px; margin-right:10px;'><a target='_blank' class='button-primary' rel='noopener noreferrer' href='https://wordpress.org/support/plugin/wp-smart-content/'>Need some support?</a></p></div>";
			$str = $str . "<div class='wrap'>";
			$str = $str . "<span id='wpscmain' style='clear:both; float:left; width:100%;'></span>";
			$str = $str . "<h2 style='clear:both; float:left; width:100%; padding-bottom:20px'>" . __( 'Add Content Block', 'wpsc' ) . '</h2>';
			$str = $str . "<div style='clear:both; float:left; width:100%;' id='plugin-messages'></div>";
			$str = $str . "<form style='clear:both; float:left; margin-top:0px;' id='wpsc_form' action='options.php' method='post'>";
			echo $str;
			settings_fields( 'wpsc_options_group' );
			do_settings_sections( 'wpsc_settings' );
			$str = "<input name='Submit' type='submit' class='button-primary' style='margin-top:20px;' value='" . __( 'Add Content', 'wpsc' ) . "' />";
			$str = $str . "<input name='Reset' type='button' class='button-primary' style='margin-top:20px; margin-left:20px;' value='" . __( 'Reset Content', 'wpsc' ) . "' onclick=\"jQuery('#wpsc_name').val(''); jQuery('#wpsc_content').val(''); jQuery('#wpsc_where').val('wp_print_footer_scripts'); jQuery('#wpsc_posts').val('0');\" />";
			$str = $str . '</form>';
			$str = $str . "<h2 style='clear:both; float:left; width:100%; margin-top:30px; margin-bottom:0px;'>" . __( 'List Content Blocks', 'wpsc' ) . '</h2>';
			echo $str;
			$this->display_admin_content();
			$str = '</div>';
			$str = $str . "<div class='table info' style='width:97%;'><p><strong>" . __( "The content needs to be 'Published' to be pushed in the theme.", 'wpsc' ) . '<br />' . __( 'The content provided is safely ignored if it is not supported by the theme.', 'wpsc' ) . '</strong></p></div></div>';
			echo $str;
			$str = "<script type='text/javascript'>window.location.hash ='#wpscmain';</script>";
			$str = $str . '</div>';
			echo $str;
		}

		/**
		 * Settings.
		 *
		 * @return void
		 */
		public function register_options() {
			register_setting( 'wpsc_options_group', 'wpsc_options_data', array( $this, 'validate_and_insert' ) );

			add_settings_section(
				'wpsc_section',
				'',
				function () {
					echo '';
				},
				'wpsc_settings'
			);

			// Displaying code block name - Escaped.
			add_settings_field(
				'wpsc_field_name',
				__( 'Please provide name for the code block: ', 'wpsc' ),
				function () {
					$wpsc_field_name = get_option( 'wpsc_field_name' );
					echo "<input id='wpsc_name' name='wpsc_options_data[wpsc_field_name]' type='text' style='clear:both; float:left; width:100%;'  value='" . esc_html( wp_unslash( $wpsc_field_name ) ) . "' />";
				},
				'wpsc_settings',
				'wpsc_section'
			);

			// Displaying code block - Textarea escaped.
			add_settings_field(
				'wpsc_field_content',
				__( 'Please provide the content to be added: ', 'wpsc' ),
				function () {
					$wpsc_field_content = get_option( 'wpsc_field_content' );
					echo "<textarea id='wpsc_content' name='wpsc_options_data[wpsc_field_content]'  style='clear:both; float:left; width:100%; height:400px'>" . wp_unslash( $wpsc_field_content ) . '</textarea>';
				},
				'wpsc_settings',
				'wpsc_section'
			);

			// Displaying code location - No need to escape.
			add_settings_field(
				'wpsc_field_where',
				__( 'Where do you want to add the content: ', 'wpsc' ),
				function () {
					$wpsc_field_where = get_option( 'wpsc_field_where' );
					if ( '' === $wpsc_field_where ) {
						$wpsc_field_where = 'wp_print_footer_scripts';
					}
					echo "<select id='wpsc_where' name='wpsc_options_data[wpsc_field_where]' style='clear:both; float:left; width:100%;' >" .
						'<option ' . ( 'wp_print_styles' === $wpsc_field_where ? "selected='selected'" : '' ) . " value='wp_print_styles'>" . esc_html__( 'Before queued styles are displayed', 'wpsc' ) . '</option>' .
						'<option ' . ( 'wp_print_scripts' === $wpsc_field_where ? "selected='selected'" : '' ) . " value='wp_print_scripts'>" . esc_html__( 'Before queued scripts are displayed', 'wpsc' ) . '</option>' .
						'<option ' . ( 'wp_head' === $wpsc_field_where ? "selected='selected'" : '' ) . "  value='wp_head'>" . esc_html__( 'Inside head tag', 'wpsc' ) . '</option>' .
						'<option ' . ( 'wp_meta' === $wpsc_field_where ? "selected='selected'" : '' ) . "  value='wp_meta'>" . esc_html__( 'Before displaying sidebar content.', 'wpsc' ) . '</option>' .
						'<option ' . ( 'wp_footer' === $wpsc_field_where ? "selected='selected'" : '' ) . "  value='wp_footer'>" . esc_html__( 'Before determining which footer template to load', 'wpsc' ) . '</option>' .
						'<option ' . ( 'wp_print_footer_scripts' === $wpsc_field_where ? "selected='selected'" : '' ) . "  value='wp_print_footer_scripts'>" . esc_html__( 'When footer scripts are displayed', 'wpsc' ) . '</option>' .
						'</select>';
				},
				'wpsc_settings',
				'wpsc_section'
			);

			// Displaying post and page titles - No need to escape.
			add_settings_field(
				'wpsc_field_posts',
				__( 'Please multi-select related posts: ', 'wpsc' ) . '<br>(' . __( 'If unselected it applies to all', 'wpsc' ) . ')&nbsp;&nbsp;',
				function () {
					$wpsc_field_posts = get_option( 'wpsc_field_posts' );

					$select_posts = "<select id='wpsc_posts' name='wpsc_options_data[wpsc_field_posts][]' multiple='multiple' style='clear:both; float:left; width:100%;; height:400px;' >";

					$categories = get_categories(
						array(
							'orderby' => 'name',
							'order'   => 'asc',
						)
					);
					foreach ( $categories as $category ) {
						$cat_posts = new WP_Query(
							array(
								'category_name' => $category->slug,
								'orderby'       => 'title',
							)
						);
						if ( $cat_posts->have_posts() ) {
							$select_posts = $select_posts . "<optgroup label='" . __( 'Posts : ', 'wpsc' ) . ucfirst( $category->slug ) . "'>";
							while ( $cat_posts->have_posts() ) {
								$cat_posts->the_post();
								$select_posts = $select_posts . '<option ' . ( is_array( $wpsc_field_posts ) && in_array( get_the_ID(), $wpsc_field_posts, true ) ? "selected='selected'" : '' ) . " value='" . get_the_ID() . "'>" . ucfirst( get_the_title() ) . '</option>';
							}
							$select_posts = $select_posts . '</optgroup>';
						}
					}

					$pages = get_pages();
					if ( count( $pages ) > 0 ) {
						$select_posts = $select_posts . "<optgroup label='Pages'>";
						foreach ( $pages as $page ) {
							$select_posts = $select_posts . '<option ' . ( is_array( $wpsc_field_posts ) && in_array( $page->ID, $wpsc_field_posts, true ) ? "selected='selected'" : '' ) . " value='" . $page->ID . "'>" . ucfirst( $page->post_title ) . '</option>';
						}
						$select_posts = $select_posts . '</optgroup>';
					}

					$select_posts = $select_posts . '</select>';

					wp_reset_postdata();

					echo $select_posts;
				},
				'wpsc_settings',
				'wpsc_section'
			);
		}

		/**
		 * Displays the wp_smart_content Posts.
		 *
		 * @return void
		 */
		public function display_admin_content() {
			global $wpdb;
			$cnt = 0;

			$str  = "<div id='table' style='clear:both; width:100%;'>";
			$rows = $wpdb->get_results( "SELECT ID, post_title, post_content, post_status, pinged, post_excerpt FROM {$wpdb->prefix}posts WHERE post_type='wp_smart_content' AND post_status IN ('draft', 'publish') ORDER BY post_date DESC", OBJECT );
			if ( null !== $rows ) {
				foreach ( $rows as $row ) {
					$cnt++;

					if ( 'draft' === $row->post_status ) {
						$str = $str . "<div id='table_row_" . $row->ID . "' class='table' style='border-color:gray;'>";
					} else {
						$str = $str . "<div id='table_row_" . $row->ID . "' class='table'>";
					}

					// Displaying code block name - Escaped.
					$str = $str . "<div class='table_row'><td><h4><span style='font-weight:bold'>#" . $cnt . '</span>&nbsp;&nbsp;Code Block: <span style="font-weight:bold">' . esc_html( $row->post_title ) . '.</span></h4></div>';

					// Displaying code location - No need to escape.
					$str = $str . '<div class="table_row"><td><h4>Code Location: <span style="font-weight:bold">';
					switch ( $row->pinged ) {
						case 'wp_print_styles':
							$str = $str . __( 'Before queued styles are displayed.', 'wpsc' );
							break;
						case 'wp_print_scripts':
							$str = $str . __( 'Before queued scripts are displayed.', 'wpsc' );
							break;
						case 'wp_head':
							$str = $str . __( 'Inside head tag.', 'wpsc' );
							break;
						case 'wp_meta':
							$str = $str . __( 'Before displaying sidebar content.', 'wpsc' );
							break;
						case 'wp_footer':
							$str = $str . __( 'Before determining which footer template to load.', 'wpsc' );
							break;
						case 'wp_print_footer_scripts':
							$str = $str . __( 'When footer scripts are displayed.', 'wpsc' );
							break;
					}
					$str = $str . '</span></h4></div>';

					// Displaying post and page titles - No need to escape.
					$post_str = '';
					unset( $post_id_arr );
					$post_id_arr = explode( '|', $row->post_excerpt );
					foreach ( $post_id_arr as $post_id ) {
						if ( $post_id > 0 ) {
							$post_str = $post_str . "<a href='" . get_the_permalink( $post_id ) . "' target='_blank' style='font-weight:bold'>" . get_the_title( $post_id ) . '</a> | ';
						}
					}

					if ( '' === $post_str ) {
						$post_str = '<span style="font-weight:bold">All Posts</span>';
					} else {
						$post_str = trim( $post_str, ' | ' );
					}

					$str = $str . '<div class="table_row"><h4>Related Posts: ' . $post_str . '.</h4></div>';

					// Displaying code block - Textarea escaped.
					$str = $str . "<div class='table_row'><textarea id='textarea_" . $row->ID . "'style='clear:both; float:left; width:100%; height:400px'>" . $row->post_content . '</textarea></div>';

					$str = $str . "<div class='table_row'><input name='wpsc_ajax_update' id='wpsc_ajax_update_button_" . $row->ID . "' style='margin-top:20px; margin-right:20px;' type='button' class='button-primary' onclick='wpsc_ajax_update_post(" . $row->ID . ");' value='" . __( 'Update Content', 'wpsc' ) . "' />";
					if ( 'publish' === $row->post_status ) {
						$str = $str . "<input name='wpsc_ajax_toggle_status' id='wpsc_ajax_toggle_status_button_" . $row->ID . "' style='margin-top:20px; margin-right:20px;' type='button' class='button-primary' onclick='wpsc_ajax_toggle_status_post(" . $row->ID . ");' value='" . __( 'Unpublish Content', 'wpsc' ) . "' />";
					} elseif ( 'draft' === $row->post_status ) {
						$str = $str . "<input name='wpsc_ajax_toggle_status' id='wpsc_ajax_toggle_status_button_" . $row->ID . "' style='margin-top:20px; margin-right:20px;' type='button' class='button-primary' onclick='wpsc_ajax_toggle_status_post(" . $row->ID . ");' value='" . __( 'Publish Content', 'wpsc' ) . "' />";
					}
					$str = $str . "<input name='wpsc_ajax_delete' id='wpsc_ajax_delete_button_" . $row->ID . "' style='margin-top:20px;' type='button' class='button-primary' onclick='wpsc_ajax_delete_post(" . $row->ID . ");' value='" . __( 'Delete Content', 'wpsc' ) . "' /></div></div>";
				}
			}
			$str = $str . '</div>';

			if ( 0 === $cnt ) {
				$str = "<p style='clear:both; float:left; width:100%;'>Sorry, No content blocks have been added yet.</p>";
			}
			echo $str;
		}

		/**
		 * Validates and inserts the wp_smart_content option on the Posts.
		 *
		 * @param object $input Form input.
		 *
		 * @return object $valid_input Valid form input.
		 */
		public function validate_and_insert( $input ) {
			$message = null;
			$type    = null;

			$wpsc_field_name = wp_slash( trim( $input['wpsc_field_name'] ) );
			if ( strlen( $wpsc_field_name ) > 0 ) {
				update_option( 'wpsc_field_name', $wpsc_field_name );
				$valid_input['wpsc_field_name'] = $wpsc_field_name;
			} else {
				$type    = 'error';
				$message = __( 'Please provide a valid name.', 'wpsc' );
				add_settings_error( 'wpsc_options_data', 'wpsc_field_name', $message, $type );
			}

			$wpsc_field_content = wp_slash( trim( $input['wpsc_field_content'] ) );
			if ( strlen( $wpsc_field_content ) > 0 ) {
				update_option( 'wpsc_field_content', $wpsc_field_content );
				$valid_input['wpsc_field_content'] = $wpsc_field_content;
			} else {
				$type    = 'error';
				$message = __( 'Please provide valid content.', 'wpsc' );
				add_settings_error( 'wpsc_options_data', 'wpsc_field_content', $message, $type );
			}

			$wpsc_field_where = $input['wpsc_field_where'];
			update_option( 'wpsc_field_where', $wpsc_field_where );
			$valid_input['wpsc_field_where'] = $wpsc_field_where;

			if ( isset( $input['wpsc_field_posts'] ) ) {
				$wpsc_field_posts = $input['wpsc_field_posts'];
				$wpsc_field_posts = array_map( 'intval', $wpsc_field_posts );
			} else {
				$wpsc_field_posts = array( 0 );
			}
			update_option( 'wpsc_field_posts', $wpsc_field_posts );
			$valid_input['wpsc_field_posts'] = $wpsc_field_posts;

			if ( null === $type ) {
				global $wpdb;

				$user_id  = get_current_user_id();
				$defaults = array(
					'post_author'           => $user_id,
					'post_content'          => $wpsc_field_content,
					'post_content_filtered' => '',
					'post_title'            => $wpsc_field_name,
					'post_excerpt'          => '|' . implode( '|', $wpsc_field_posts ) . '|',
					'post_status'           => 'publish',
					'post_type'             => 'wp_smart_content',
					'comment_status'        => 'closed',
					'ping_status'           => '',
					'post_password'         => '',
					'to_ping'               => '',
					'pinged'                => $wpsc_field_where,
					'post_parent'           => 0,
					'menu_order'            => 0,
					'guid'                  => '',
					'import_id'             => 0,
					'context'               => '',
				);
				wp_insert_post( $defaults ); // Only administrator can insert.

				$type    = 'updated';
				$message = __( 'Content successfully added.', 'wpsc' );
				add_settings_error( 'wpsc_options_data', 'wpsc_field_error', $message, $type );
			}

			return $valid_input;
		}

		/**
		 * --------------------------------Frontend Section-----------------------------------------.
		 */

		/**
		 * Displays display_content on the front end based on type.
		 * Post Id is available in the frontend page.
		 *
		 * @return void
		 */
		public function display_frontend_content() {
			global $wpdb;
			$post_id = get_the_ID();

			$where = current_filter(); // Current hook.

			$rows = $wpdb->get_results( $wpdb->prepare( "SELECT post_content FROM {$wpdb->prefix}posts WHERE post_type='wp_smart_content' AND post_status='publish' AND pinged=%s AND (post_excerpt LIKE %s OR post_excerpt = '|0|') ORDER BY post_date DESC", $where, '%|' . $wpdb->esc_like( $post_id ) . '|%' ), OBJECT );
			if ( null !== $rows ) {
				foreach ( $rows as $row ) {
					$content = $row->post_content;  // Do not sanitize as it would strip script tags and so on. Additionally do not remove slashes.
					echo $content;
				}
			}

		}

		/**
		 * --------------------------------AJAX Section-----------------------------------------.
		 */

		/**
		 * AJAX update post.
		 * Updates the wp_smart_content based on the post id and post content.
		 *
		 * @return void
		 */
		public function wp_ajax_wpsc_update_post() {
			global $wpdb;

			if ( wp_verify_nonce( isset( $_POST['nonce'] ) ? filter_var( wp_unslash( $_POST['nonce'] ), FILTER_SANITIZE_STRING ) : '', 'wpsc_nonce' ) ) {
				// Only administrator can update.
				if ( current_user_can( 'manage_options' ) ) {
					if ( isset( $_POST['post_id'] ) && isset( $_POST['content'] ) ) {
						$post_id = intval( $_POST['post_id'], 10 );
						$content = wp_unslash( $_POST['content'] ); // Do not sanitize as it would strip script tags and so on. Remove slashes using wp_slash().
						$rows    = $wpdb->get_results( $wpdb->prepare( "UPDATE {$wpdb->prefix}posts SET post_content = %s WHERE post_type='wp_smart_content' AND post_status IN ('draft', 'publish') AND ID = %d", $content, $post_id ) );
					}
				}
			}

			wp_die(); // Plugin is required to terminate immediately and return a proper response.
		}

		/**
		 * AJAX delete post.
		 * Toggles the post status based on the post id.
		 * Draft post status is switched to published and vice versa.
		 *
		 * @return void
		 */
		public function wp_ajax_wpsc_toggle_status_post() {
			global $wpdb;

			if ( isset( $_POST ) ) {
				$_POST = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );
			}

			if ( wp_verify_nonce( isset( $_POST['nonce'] ) ? filter_var( wp_unslash( $_POST['nonce'] ), FILTER_SANITIZE_STRING ) : '', 'wpsc_nonce' ) ) {
				// Only administrator can change post status.
				if ( current_user_can( 'manage_options' ) ) {
					if ( isset( $_POST['post_id'] ) ) {
						$post_id = intval( $_POST['post_id'], 10 );
						$rows    = $wpdb->get_results( $wpdb->prepare( "UPDATE {$wpdb->prefix}posts SET post_status = CASE post_status WHEN 'draft' THEN 'publish' WHEN 'publish' THEN 'draft' ELSE post_status END WHERE post_type='wp_smart_content' AND post_status IN ('draft', 'publish') AND ID = %d", $post_id ) );
					}
				}
			}

			wp_die(); // Plugin is required to terminate immediately and return a proper response.
		}

		/**
		 * AJAX delete post.
		 * Deletes the wp_smart_content based on the post id.
		 *
		 * @return void
		 */
		public function wp_ajax_wpsc_delete_post() {
			global $wpdb;

			if ( isset( $_POST ) ) {
				$_POST = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );
			}

			if ( wp_verify_nonce( isset( $_POST['nonce'] ) ? filter_var( wp_unslash( $_POST['nonce'] ), FILTER_SANITIZE_STRING ) : '', 'wpsc_nonce' ) ) {
				// Only administrator can delete.
				if ( current_user_can( 'manage_options' ) ) {
					if ( isset( $_POST['post_id'] ) ) {
						$post_id = intval( $_POST['post_id'], 10 );
						$rows    = $wpdb->get_results( $wpdb->prepare( "DELETE FROM {$wpdb->prefix}posts WHERE post_type='wp_smart_content' AND post_status IN ('draft', 'publish') AND ID = %d", $post_id ) );
					}
				}
			}

			wp_die(); // Plugin is required to terminate immediately and return a proper response.
		}

		/**
		 * --------------------------------Utility Section-----------------------------------------.
		 */

		/**
		 * Check if frontend.
		 *
		 * @return boolean Returns true if front end page; else false.
		 */
		public function is_frontend() {
			$path_array = str_replace( array( '\\', '/' ), DIRECTORY_SEPARATOR, ABSPATH );
			$php_self   = filter_input( INPUT_SERVER, 'PHP_SELF', FILTER_SANITIZE_URL );
			return ( ! ( is_admin() || wp_doing_ajax() || in_array( $path_array . 'wp-login.php', get_included_files(), true ) || in_array( $path_array . 'wp-register.php', get_included_files(), true ) ) || 'wp-login.php' === $GLOBALS['pagenow'] || '/wp-login.php' === $php_self );
		}
	}

	// Initialize.
	WPSC::get_instance();
endif;
